==> applet-service-2.0.0-20200812.035905-16-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandMenberBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

@Data
public class AppletBrandMenberBo implements Serializable {
    private static final long serialVersionUID = -8972727807180576307L;

    @ApiModelProperty(value = "sysBrandId", name = "sysBrandId", example = "品牌id")
    private Long sysBrandId;

    @ApiModelProperty(value = "memberCode", name = "memberCode", example = "memberCode")
    private String memberCode;

    @ApiModelProperty(value = "isOpenCard", name = "isOpenCard", example = "是否开卡,true,false")
    private boolean isOpenCard;

    @ApiModelProperty(value = "oderMemberCode", name = "oderMemberCode", example = "oderMemberCode")
    private String oderMemberCode;

    @ApiModelProperty(value = "phone", name = "phone", example = "手机号")
    private String phone;

    @ApiModelProperty(value = "mktTaskId", name = "mktTaskId", example = "mktTaskId")
    private String mktTaskId;

    @ApiModelProperty(value = "propertyCode", name = "propertyCode", example = "propertyCode")
    private String propertyCode;

    @ApiModelProperty(value = "sysCompanyId", name = "sysCompanyId", example = "sysCompanyId")
    private Long sysCompanyId;

    @ApiModelProperty(value = "skipByBrandId", name = "skipByBrandId", example = "skipByBrandId")
    private String skipByBrandId;

    @ApiModelProperty(value = "activityNo", name = "activityNo", example = "activityNo")
    private String activityNo;

    @ApiModelProperty(value = "activityOrdersNo", name = "activityOrdersNo", example = "activityOrdersNo")
    private String activityOrdersNo;

    @ApiModelProperty(value = "openId", name = "openId", example = "openId")
    private String openId;

    @ApiModelProperty(value = "unionId", name = "unionId", example = "unionId")
    private String unionId;

    @ApiModelProperty(value = "appid", name = "appid", example = "appid")
    private String appid;

    @ApiModelProperty(value = "userInfoData", name = "userInfoData", example = "userInfoData")
    private String userInfoData;

    private AppletByCodeBo appletByCodeBo;

}

==> applet-service-2.0.2-20210924.080855-12-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandMenberBo.java <==
package com.bizvane.appletservice.models.bo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

@Data
public class AppletBrandMenberBo implements Serializable {
    private static final long serialVersionUID = -8972727807180576307L;

    @ApiModelProperty(value = "sysBrandId", name = "sysBrandId", example = "品牌id")
    private Long sysBrandId;

    @ApiModelProperty(value = "memberCode", name = "memberCode", example = "memberCode")
    private String memberCode;

    @ApiModelProperty(value = "isOpenCard", name = "isOpenCard", example = "是否开卡,true,false")
    private boolean isOpenCard;

    @ApiModelProperty(value = "isOpenWxElectCard", name = "isOpenWxElectCard", example = "是否开过电子会员卡")
    private boolean isOpenWxElectCard;

    @ApiModelProperty(value = "oderMemberCode", name = "oderMemberCode", example = "oderMemberCode")
    private String oderMemberCode;

    @ApiModelProperty(value = "phone", name = "phone", example = "手机号")
    private String phone;

    @ApiModelProperty(value = "mktTaskId", name = "mktTaskId", example = "mktTaskId")
    private String mktTaskId;

    @ApiModelProperty(value = "propertyCode", name = "propertyCode", example = "propertyCode")
    private String propertyCode;

    @ApiModelProperty(value = "sysCompanyId", name = "sysCompanyId", example = "sysCompanyId")
    private Long sysCompanyId;

    @ApiModelProperty(value = "skipByBrandId", name = "skipByBrandId", example = "skipByBrandId")
    private String skipByBrandId;

    @ApiModelProperty(value = "activityNo", name = "activityNo", example = "activityNo")
    private String activityNo;

    @ApiModelProperty(value = "activityOrdersNo", name = "activityOrdersNo", example = "activityOrdersNo")
    private String activityOrdersNo;

    @ApiModelProperty(value = "openId", name = "openId", example = "openId")
    private String openId;

    @ApiModelProperty(value = "unionId", name = "unionId", example = "unionId")
    private String unionId;

    @ApiModelProperty(value = "appid", name = "appid", example = "appid")
    private String appid;

    @ApiModelProperty(value = "userInfoData", name = "userInfoData", example = "userInfoData")
    private String userInfoData;

    private AppletByCodeBo appletByCodeBo;

    private String userId;

}
